==> kubernetes-model-1.0.16-sources.jar: annotations/io/fabric8/openshift/api/model/BuildConfigStatusBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;

public class BuildConfigStatusBuilder extends BuildConfigStatusFluent<BuildConfigStatusBuilder> implements VisitableBuilder<BuildConfigStatus,BuildConfigStatusBuilder>{

     BuildConfigStatusFluent<?> fluent;
public BuildConfigStatusBuilder(){
    this(new BuildConfigStatus());
}
public BuildConfigStatusBuilder( BuildConfigStatusFluent<?> fluent ){
    this(fluent, new BuildConfigStatus());
}
public BuildConfigStatusBuilder( BuildConfigStatusFluent<?> fluent , BuildConfigStatus instance ){
    this.fluent = fluent; fluent.withLastVersion(instance.getLastVersion()); 
}
public BuildConfigStatusBuilder( BuildConfigStatus instance ){
    this.fluent = this; this.withLastVersion(instance.getLastVersion()); 
}

public EditableBuildConfigStatus build(){
    EditableBuildConfigStatus buildable = new EditableBuildConfigStatus(fluent.getLastVersion());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
BuildConfigStatusBuilder that = (BuildConfigStatusBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.36-sources.jar: annotations/io/fabric8/openshift/api/model/BuildConfigStatusBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Builder;

public class BuildConfigStatusBuilder extends BuildConfigStatusFluentImpl<BuildConfigStatusBuilder> implements VisitableBuilder<BuildConfigStatus,BuildConfigStatusBuilder>{

     BuildConfigStatusFluent<?> fluent;
public BuildConfigStatusBuilder(){
    this(new BuildConfigStatus());
}
public BuildConfigStatusBuilder( BuildConfigStatusFluent<?> fluent ){
    this(fluent, new BuildConfigStatus());
}
public BuildConfigStatusBuilder( BuildConfigStatusFluent<?> fluent , BuildConfigStatus instance ){
    this.fluent = fluent; fluent.withLastVersion(instance.getLastVersion()); 
}
public BuildConfigStatusBuilder( BuildConfigStatus instance ){
    this.fluent = this; this.withLastVersion(instance.getLastVersion()); 
}

public EditableBuildConfigStatus build(){
    EditableBuildConfigStatus buildable = new EditableBuildConfigStatus(fluent.getLastVersion());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
BuildConfigStatusBuilder that = (BuildConfigStatusBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
